@@ -44,12 +44,12 @@ public:
         BatchExec,       /// < Not implemented.
         BookmarkMouseUp, /// < Not implemented.
         ConsoleExec,     /// < Not implemented.
-        DocDidPrint,     /// < Not implemented.
-        DocDidSave,      /// < Not implemented.
-        DocOpen,         /// < Not implemented.
-        DocWillClose,    /// < Not implemented.
-        DocWillPrint,    /// < Not implemented.
-        DocWillSave,     /// < Not implemented.
+        DocDidPrint,     /// < When a document is printed.
+        DocDidSave,      /// < When a document is saved.
+        DocOpen,         /// < This event is triggered when a document is opened. The document level script functions are scanned and any exposed scripts are executed
+        DocWillClose,    /// < When a document is about to be closed.
+        DocWillPrint,    /// < When a document is about to be printed.
+        DocWillSave,     /// < When a document is about to be saved.
         ExternalExec,    /// < Not implemented.
         FieldBlur,       /// < Not implemented.
         FieldCalculate,  /// < This event is defined in a field re-calculation.
@@ -111,12 +111,19 @@ public:
     QString change() const;
     void setChange(const QString &change);
 
+    int selStart() const;
+    void setSelStart(const int selStart);
+
+    int selEnd() const;
+    void setSelEnd(const int selEnd);
+
     static std::shared_ptr<Event> createFormCalculateEvent(FormField *target, Page *targetPage, FormField *source = nullptr, Page *sourcePage = nullptr, const QString &targetName = QString());
     static std::shared_ptr<Event> createFormatEvent(FormField *target, Page *targetPage, const QString &targetName = QString());
     static std::shared_ptr<Event> createKeystrokeEvent(FormField *target, Page *targetPage);
     static std::shared_ptr<Event> createFormFocusEvent(FormField *target, Page *targetPage, const QString &targetName = QString());
     static std::shared_ptr<Event> createFormValidateEvent(FormField *target, Page *targetPage, const QString &targetName = QString());
     static std::shared_ptr<Event> createFieldMouseUpEvent(FormField *target, Page *targetPage);
+    static std::shared_ptr<Event> createDocEvent(Event::EventType type);
 
 private:
     class Private;
